"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
/**
 * Uses the underlying Writable stream to output GTFS data
 */
class CSVStream extends stream_1.Transform {
    constructor(fields, key = null) {
        super({ encoding: "utf8", objectMode: true });
        this.fields = fields;
        this.key = key;
        this.headerSent = false;
        this.seenKeys = {};
    }
    /**
     * Write the given entity to the file stream
     */
    _transform(data, encoding, callback) {
        if (!this.headerSent) {
            this.push(this.fields.join() + "\n");
            this.headerSent = true;
        }
        const key = this.key ? data[this.key] : null;
        if (!key || !this.seenKeys[key]) {
            this.seenKeys[key] = true;
            const fields = this.fields.map(f => this.quote(data[f]));
            this.push(fields.join() + "\n");
        }
        callback();
    }
    quote(text) {
        return typeof text === "string" && text.includes(",") ? "\"" + text + "\"" : text;
    }
}
exports.CSVStream = CSVStream;
