"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Merges multiple GTFS sets into a single stream for each GTFS file (stops.txt etc)
 */
class GTFSOutput {
    constructor(calendar, stopsAndTransfers, stopTimes, trips, agencies, routes) {
        this.calendar = calendar;
        this.stopsAndTransfers = stopsAndTransfers;
        this.stopTimes = stopTimes;
        this.trips = trips;
        this.agencies = agencies;
        this.routes = routes;
    }
    /**
     * Merge in the given GTFS data set and push the new items to the file streams.
     */
    async write(gtfs) {
        const tripIdMap = await this.writeCalendarsAndTrips(gtfs);
        const usedStops = await this.stopTimes.write(gtfs.stopTimes, tripIdMap, gtfs.parentStops);
        await Promise.all([
            this.stopsAndTransfers.write(gtfs.stops, gtfs.transfers, gtfs.parentStops, usedStops),
            this.agencies.write(gtfs.agencies),
            this.routes.write(gtfs.routes)
        ]);
    }
    async writeCalendarsAndTrips(gtfs) {
        const serviceIdMap = await this.calendar.write(gtfs.calendars, gtfs.calendarDates);
        return this.trips.write(gtfs.trips, serviceIdMap);
    }
    async end() {
        await Promise.all([
            this.calendar.end(),
            this.stopsAndTransfers.end(),
            this.stopTimes.end(),
            this.trips.end(),
            this.agencies.end(),
            this.routes.end()
        ]);
    }
}
exports.GTFSOutput = GTFSOutput;
