"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const rimraf_1 = require("rimraf");
const GTFSOutput_1 = require("./GTFSOutput");
const CalendarMerger_1 = require("./merger/CalendarMerger");
const MemoizedSequence_1 = require("../sequence/MemoizedSequence");
const StopsAndTransfersMerger_1 = require("./merger/StopsAndTransfersMerger");
const StopTimesMerger_1 = require("./merger/StopTimesMerger");
const TripsMerger_1 = require("./merger/TripsMerger");
const GenericMerger_1 = require("./merger/GenericMerger");
const CSVStream_1 = require("../csv/CSVStream");
const Sequence_1 = require("../sequence/Sequence");
class GTFSOutputFactory {
    constructor(calendarFactory, tempFolder, ruler, transferDistance) {
        this.calendarFactory = calendarFactory;
        this.tempFolder = tempFolder;
        this.ruler = ruler;
        this.transferDistance = transferDistance;
    }
    create() {
        if (fs.existsSync(this.tempFolder)) {
            rimraf_1.sync(this.tempFolder);
        }
        fs.mkdirSync(this.tempFolder);
        const calendarStream = new CSVStream_1.CSVStream([
            "service_id",
            "monday",
            "tuesday",
            "wednesday",
            "thursday",
            "friday",
            "saturday",
            "sunday",
            "start_date",
            "end_date"
        ], "service_id");
        calendarStream.pipe(fs.createWriteStream(this.tempFolder + "calendar.txt"));
        const calendarDatesStream = new CSVStream_1.CSVStream([
            "service_id",
            "date",
            "exception_type"
        ]);
        calendarDatesStream.pipe(fs.createWriteStream(this.tempFolder + "calendar_dates.txt"));
        const tripsStream = new CSVStream_1.CSVStream([
            "route_id",
            "service_id",
            "trip_id",
            "trip_headsign",
            "trip_short_name",
            "direction_id",
            "wheelchair_accessible",
            "bikes_allowed"
        ]);
        tripsStream.pipe(fs.createWriteStream(this.tempFolder + "trips.txt"));
        const stopTimesStream = new CSVStream_1.CSVStream([
            "trip_id",
            "arrival_time",
            "departure_time",
            "stop_id",
            "stop_sequence",
            "stop_headsign",
            "pickup_type",
            "drop_off_type",
            "shape_dist_traveled",
            "timepoint"
        ]);
        stopTimesStream.pipe(fs.createWriteStream(this.tempFolder + "stop_times.txt"));
        const routesStream = new CSVStream_1.CSVStream([
            "route_id",
            "agency_id",
            "route_short_name",
            "route_long_name",
            "route_type",
            "route_text_color",
            "route_color",
            "route_url",
            "route_desc"
        ], "route_id");
        routesStream.pipe(fs.createWriteStream(this.tempFolder + "routes.txt"));
        const agencyStream = new CSVStream_1.CSVStream([
            "agency_id",
            "agency_name",
            "agency_url",
            "agency_timezone",
            "agency_lang",
            "agency_phone",
            "agency_fare_url"
        ], "agency_id");
        agencyStream.pipe(fs.createWriteStream(this.tempFolder + "agency.txt"));
        const stopsStream = new CSVStream_1.CSVStream([
            "stop_id",
            "stop_code",
            "stop_name",
            "stop_desc",
            "stop_lat",
            "stop_lon",
            "zone_id",
            "stop_url",
            "location_type",
            "parent_station",
            "stop_timezone",
            "wheelchair_boarding"
        ], "stop_id");
        stopsStream.pipe(fs.createWriteStream(this.tempFolder + "stops.txt"));
        const transfersStream = new CSVStream_1.CSVStream([
            "from_stop_id",
            "to_stop_id",
            "transfer_type",
            "min_transfer_time"
        ]);
        transfersStream.pipe(fs.createWriteStream(this.tempFolder + "transfers.txt"));
        return new GTFSOutput_1.GTFSOutput(new CalendarMerger_1.CalendarMerger(calendarStream, calendarDatesStream, this.calendarFactory, new MemoizedSequence_1.MemoizedSequence()), new StopsAndTransfersMerger_1.StopsAndTransfersMerger(stopsStream, transfersStream, this.ruler, this.transferDistance), new StopTimesMerger_1.StopTimesMerger(stopTimesStream), new TripsMerger_1.TripsMerger(tripsStream, new Sequence_1.Sequence()), new GenericMerger_1.GenericMerger(agencyStream), new GenericMerger_1.GenericMerger(routesStream));
    }
}
exports.GTFSOutputFactory = GTFSOutputFactory;
