"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
/**
 * Merges a list of input GTFS files into a single output file
 */
class MergeCommand {
    constructor(gtfsLoader, outputFactory, zipOutput) {
        this.gtfsLoader = gtfsLoader;
        this.outputFactory = outputFactory;
        this.zipOutput = zipOutput;
    }
    /**
     * Iterate over the list of inputs loading and merging each one at a time.
     */
    async run(inputs, outputFile, stopPrefix, filterDatesBefore) {
        const output = this.outputFactory.create();
        for (const input of inputs) {
            console.log("Loading " + input);
            const file = fs.createReadStream(input);
            const gtfs = await this.gtfsLoader.load(file, stopPrefix, filterDatesBefore);
            console.log("Processing " + input);
            await output.write(gtfs);
        }
        await output.end();
        await this.zipOutput.write(outputFile);
    }
}
exports.MergeCommand = MergeCommand;
