"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class CalendarMerger {
    constructor(calendar, calendarDates, calendarFactory, serviceIdSequence) {
        this.calendar = calendar;
        this.calendarDates = calendarDates;
        this.calendarFactory = calendarFactory;
        this.serviceIdSequence = serviceIdSequence;
    }
    async write(calendars, dateIndex) {
        const serviceIdMap = {};
        for (const calendar of calendars) {
            const calendarDates = dateIndex[calendar.service_id] || [];
            await this.writeCalendar(calendar, calendarDates, serviceIdMap);
        }
        // check for any calendar dates that have no calendar entry
        for (const serviceId of Object.keys(dateIndex)) {
            if (!serviceIdMap[serviceId]) {
                const [calendar, calendarDates] = this.calendarFactory.create(serviceId, dateIndex[serviceId]);
                await this.writeCalendar(calendar, calendarDates, serviceIdMap);
            }
        }
        return serviceIdMap;
    }
    async writeCalendar(calendar, calendarDates, serviceIdMap) {
        const hash = this.getCalendarHash(calendar, calendarDates);
        const alreadySeenCalendar = this.serviceIdSequence.haveSeen(hash);
        const newServiceId = this.serviceIdSequence.get(hash);
        serviceIdMap[calendar.service_id] = newServiceId;
        if (!alreadySeenCalendar) {
            calendar.service_id = newServiceId;
            await this.push(this.calendar, calendar);
            for (const calendarDay of calendarDates) {
                calendarDay.service_id = newServiceId;
                await this.push(this.calendarDates, calendarDay);
            }
        }
    }
    getCalendarHash(calendar, calendarDates) {
        const { service_id, ...rest } = calendar;
        const days = calendarDates.map(d => d.date + "_" + d.exception_type).join(":");
        const fields = Object.values({ days, ...rest });
        return fields.join();
    }
    push(stream, data) {
        const writable = stream.write(data);
        if (!writable) {
            return new Promise(resolve => stream.once("drain", () => resolve()));
        }
    }
    /**
     * Flush all the data to the output stream
     */
    async end() {
        return Promise.all([
            new Promise(resolve => this.calendar.end(resolve)),
            new Promise(resolve => this.calendarDates.end(resolve))
        ]);
    }
}
exports.CalendarMerger = CalendarMerger;
